@@ -22,19 +22,34 @@ import (
 	"log"
 	"os"
 	"path/filepath"
+	"strconv"
 	"time"
 
 	cs "github.com/SUSE/container-suseconnect/internal"
 	"github.com/SUSE/container-suseconnect/internal/regionsrv"
 )
 
+var logCredentialsErrors = false
+
 func init() {
+	value := os.Getenv("CONTAINER_SUSECONNECT_LOG_CREDENTIALS_ERR")
+	enabled, err := strconv.ParseBool(value)
+
+	if err == nil && enabled {
+		logCredentialsErrors = true
+	}
+
 	flag.BoolFunc("version", "print version and exit", func(string) error {
 		fmt.Println(cs.Version)
 		os.Exit(0)
 		return nil
 	})
 
+	flag.BoolFunc("log-credentials-errors", "log missing credentials and exit with 1", func(string) error {
+		logCredentialsErrors = true
+		return nil
+	})
+
 	flag.Usage = func() {
 		fmt.Fprintf(flag.CommandLine.Output(),
 			"container-suseconnect: Access zypper repositories from within containers"+
@@ -63,44 +78,39 @@ intended to use for debugging purposes.
 }
 
 func main() {
-	// Switch the default application behavior in relation to the basename
-	appAction := runListProducts
+	// Determine the application's action based on the binary name or command-line arguments.
+	var appAction func() error
 
 	switch filepath.Base(os.Args[0]) {
 	case "container-suseconnect-zypp":
 		appAction = runZypperPlugin
 	case "susecloud":
 		appAction = runZypperURLResolver
-	}
-
-	flag.Parse()
-
-	switch flag.Arg(0) {
-	case "lp":
-		fallthrough
-	case "list-products":
-		appAction = runListProducts
-	case "lm":
-		fallthrough
-	case "list-modules":
-		appAction = runListModules
-	case "susecloud":
-		appAction = runZypperURLResolver
-	case "z":
-		fallthrough
-	case "zypp":
-		fallthrough
-	case "zypper":
-		appAction = runZypperPlugin
 	default:
-		flag.Usage()
-		os.Exit(1)
+		flag.Parse()
+
+		// Override default action based on command-line arguments.
+		switch flag.Arg(0) {
+		case "lp", "list-products":
+			appAction = runListProducts
+		case "lm", "list-modules":
+			appAction = runListModules
+		case "susecloud":
+			appAction = runZypperURLResolver
+		case "z", "zypp", "zypper":
+			appAction = runZypperPlugin
+		default:
+			flag.Usage()
+			os.Exit(1)
+		}
 	}
 
-	// Run the application
+	// Run the application with the selected action.
 	cs.SetLoggerOutput()
 	if err := appAction(); err != nil {
-		log.Fatal(err)
+		if !cs.IsCredentialsNotFoundError(err) || logCredentialsErrors {
+			log.Fatal(err)
+		}
 	}
 }
 
@@ -129,7 +139,7 @@ func requestProducts() ([]cs.Product, error) {
 		suseConnectData.Insecure = false
 
 		if cloudCfg.Ca != "" {
-			regionsrv.SafeCAFile(cloudCfg.Ca)
+			regionsrv.SaveCAFile(cloudCfg.Ca)
 		}
 
 		regionsrv.UpdateHostsFile(cloudCfg.ServerFqdn, cloudCfg.ServerIP)
