@@ -70,12 +70,12 @@ func ReadConfiguration(config Configuration) error {
 			return nil
 		}
 
-		return loggedError(GetCredentialsError, "Warning: SUSE credentials not found: %v - automatic handling of repositories not done.", config.locations())
+		return loggedError(CredentialsNotFoundError, "SUSE Credentials not found at %v. Skipping automatic handling of repositories.", config.locations())
 	}
 
 	file, err := os.Open(path)
 	if err != nil {
-		return loggedError(GetCredentialsError, "Can't open %s file: %v", path, err.Error())
+		return loggedError(CredentialsNotFoundError, "Can't open %s file: %v", path, err.Error())
 	}
 	defer file.Close()
 
@@ -101,7 +101,7 @@ func parse(config Configuration, reader io.Reader) error {
 		parts := strings.SplitN(line, string(config.separator()), 2)
 
 		if len(parts) != 2 {
-			return loggedError(GetCredentialsError, "Can't parse line: %v", line)
+			return loggedError(InvalidCredentialsError, "Can't parse line: %v", line)
 		}
 
 		// And finally trim the key and the value and pass it to the config.
@@ -111,7 +111,7 @@ func parse(config Configuration, reader io.Reader) error {
 
 	// Final checks.
 	if err := scanner.Err(); err != nil {
-		return loggedError(GetCredentialsError, "Error when scanning configuration: %v", err)
+		return loggedError(InvalidCredentialsError, "Error when scanning configuration: %v", err)
 	}
 
 	if err := config.afterParseCheck(); err != nil {
